@@ -1,6 +1,6 @@
 #' @title Download the Data Structure Definition of a dataset
 #' @description Download Data Structure Definition (DSD) of a Eurostat dataset if it is not cached previously. 
-#' @param id a character string with the id of the dataset. It is the value from the codename column of the \code{get_eurostat_toc} function. 
+#' @param id a character string with the id of the dataset. It is the value from the codename column of the \code{\link{get_eurostat_toc}} function. 
 #' @param cache a boolean whether to load/save the TOC from/in the cache or not. The default value is \code{TRUE}, so that the TOC is checked first in the cache and if does not exist then downloaded from Eurostat and cached.
 #' @param update_cache a boolean to update cache or not. The default value is \code{FALSE}, so the cache is not updated. Can be set also with \code{options(restatapi_update=TRUE)}
 #' @param cache_dir a path to a cache directory. The default is \code{NULL}, in this case the TOC is cached in the memory (in the '.restatapi_env'). Otherwise if the \code{cache_dir} directory does not exist it creates the 'restatapi' directory in the temporary directory from \code{tempdir()} to save the RDS-file. Directory can also be set with \code{option(restatapi_cache_dir=...)}.
@@ -37,14 +37,23 @@ get_eurostat_dsd <- function(id,
                              cache_dir=NULL,
                              compress_file=TRUE,
                              verbose=FALSE,...) {
-  ne<-TRUE
   verbose<-verbose|getOption("restatapi_verbose",FALSE)
   if (is.null(id)){
     warning('No dataset id were provided.')
     dsd<-NULL
   } else {
     dsd<-NULL
-    if ((!exists(".restatapi_env"))|(length(list(...))>0)) {load_cfg(...)}
+    if((!exists(".restatapi_env")|(length(list(...))>0))){
+      if ((length(list(...))>0)) {
+        if (all(names(list(...)) %in% c("api_version","load_toc","parallel","max_cores","verbose"))){
+          load_cfg(...)  
+        } else {
+          load_cfg()
+        }
+      } else {
+        load_cfg()
+      }  
+    }
     update_cache <- update_cache | getOption("restatapi_update", FALSE)
     if ((cache) & (!update_cache)) {
       dsd<-get_eurostat_cache(paste0(id,".dsd"),cache_dir,verbose=verbose)
@@ -58,7 +67,7 @@ get_eurostat_dsd <- function(id,
         message("Trying to download the DSD from: ",dsd_endpoint)
         tryCatch({utils::download.file(dsd_endpoint,temp,get("dmethod",envir=.restatapi_env))},
                  error = function(e) {
-                   message("Unable to download the DSD file:",'\n',paste(unlist(e),collapse="\n"))
+                   message("Error by the download of the DSD file:",'\n',paste(unlist(e),collapse="\n"))
                  },
                  warning = function(w) {
                    message("Warning by the download of the DSD file:",'\n',paste(unlist(w),collapse="\n"))
@@ -67,7 +76,7 @@ get_eurostat_dsd <- function(id,
           message("Trying to extract the DSD from: ",temp)
           tryCatch({dsd_xml<-xml2::read_xml(temp)},
                  error = function(e) {
-                   message("Unable to extract the XML from the downloaded DSD file:",'\n',paste(unlist(e),collapse="\n"))
+                   message("Error during the extraction of the XML from the downloaded DSD file:",'\n',paste(unlist(e),collapse="\n"))
                    dsd_xml<-NULL
                  },
                  warning = function(w) {
